configurationtools.make_abjad_default_config_file_into_dict
===========================================================

.. autofunction:: abjad.tools.configurationtools.make_abjad_default_config_file_into_dict.make_abjad_default_config_file_into_dict
